@@ -25,28 +25,26 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 #include "archive.h"
-#include "archivefactory.h"
+#include "archivebase.h"
+#include "archiveinterface.h"
 
 #include <QByteArray>
 #include <QFile>
 #include <QFileInfo>
 
 #include <KDebug>
+#include <KPluginLoader>
 #include <KMimeType>
 #include <KMimeTypeTrader>
 #include <KServiceTypeTrader>
-#include <KLibLoader>
 
 static bool comparePlugins(const KService::Ptr &p1, const KService::Ptr &p2)
 {
     return (p1->property("X-KDE-Priority").toInt()) > (p2->property("X-KDE-Priority").toInt());
 }
 
-static QString determineMimeType(const QString & filename, const QString & defaultMimeType)
+static QString determineMimeType(const QString& filename)
 {
-    if (!defaultMimeType.isEmpty())
-        return defaultMimeType;
-
     if (!QFile::exists(filename))
         return KMimeType::findByPath(filename)->name();
 
@@ -55,69 +53,67 @@ static QString determineMimeType(const QString & filename, const QString & defau
         return QString();
 
     const qint64 maxSize = 0x100000; // 1MB
-    qint64 bufferSize = qMin(maxSize, file.size());
-    QByteArray buffer = file.read(bufferSize);
+    const qint64 bufferSize = qMin(maxSize, file.size());
+    const QByteArray buffer = file.read(bufferSize);
 
     return KMimeType::findByNameAndContent(filename, buffer)->name();
 }
 
+static KService::List findPluginOffers(const QString& filename, const QString& fixedMimeType)
+{
+    KService::List offers;
+
+    const QString mimeType = fixedMimeType.isEmpty() ? determineMimeType(filename) : fixedMimeType;
+
+    if (!mimeType.isEmpty()) {
+        offers = KMimeTypeTrader::self()->query(mimeType, "Kerfuffle/Plugin", "(exist Library)");
+        qSort(offers.begin(), offers.end(), comparePlugins);
+    }
+
+    return offers;
+}
+
 namespace Kerfuffle
 {
-Archive *factory(const QString & filename, const QString & requestedMimeType)
-{
-    kDebug(1601) ;
 
+Archive *factory(const QString& filename, const QString& fixedMimeType)
+{
     qRegisterMetaType<ArchiveEntry>("ArchiveEntry");
 
-    QString mimeType = determineMimeType(filename, requestedMimeType);
-    if (mimeType.isEmpty())
-        return 0L;
-
-    KService::List offers = KMimeTypeTrader::self()->query(mimeType, "Kerfuffle/Plugin", "(exist Library)");
+    const KService::List offers = findPluginOffers(filename, fixedMimeType);
 
     if (offers.isEmpty()) {
-        kDebug(1601) << "Trying to find the mimetype by looking at file content";
-
-        int acc;
-        QString mimeType = KMimeType::findByFileContent(filename, &acc)->name();
-        kDebug(1601) << mimeType << acc;
-        offers = KMimeTypeTrader::self()->query(mimeType, "Kerfuffle/Plugin", "(exist Library)");
+        kDebug() << "Could not find a plugin to handle" << filename;
+        return NULL;
     }
 
-    qSort(offers.begin(), offers.end(), comparePlugins);
+    const QString pluginName = offers.first()->library();
+    kDebug() << "Loading plugin" << pluginName;
 
-    if (!offers.isEmpty()) {
-        QString libraryName = offers[ 0 ]->library();
-        KLibrary *lib = KLibLoader::self()->library(QFile::encodeName(libraryName), QLibrary::ExportExternalSymbolsHint);
-        //TODO: get rid of the deprecated klibloader::self
-#if 0
-
-        KPluginLoader loader(offers.at(0));
-        KPluginFactory *factory = loader.factory();
-#endif
-
-        kDebug(1601) << "Loading library " << libraryName ;
-        if (lib) {
-            ArchiveFactory *(*pluginFactory)() = (ArchiveFactory * (*)())lib->resolveFunction("pluginFactory");
-            if (pluginFactory) {
-                ArchiveFactory *factory = pluginFactory(); // TODO: cache these
-                Archive *arch = factory->createArchive(QFileInfo(filename).absoluteFilePath(), 0);
-                delete factory;
-                return arch;
-            }
-        }
-        kDebug(1601) << "Couldn't load library " << libraryName ;
+    KPluginFactory * const factory = KPluginLoader(pluginName).factory();
+    if (!factory) {
+        kDebug() << "Invalid plugin factory for" << pluginName;
+        return NULL;
     }
-    kDebug(1601) << "Couldn't find a library capable of handling " << filename ;
-    return 0;
+
+    QVariantList args;
+    args.append(QVariant(QFileInfo(filename).absoluteFilePath()));
+
+    ReadOnlyArchiveInterface * const iface = factory->create<ReadOnlyArchiveInterface>(0, args);
+    if (!iface) {
+        kDebug() << "Could not create plugin instance" << pluginName << "for" << filename;
+        return NULL;
+    }
+
+    return new ArchiveBase(iface);
 }
 
 QStringList supportedMimeTypes()
 {
-    QString constraint("(exist Library)");
-    QLatin1String basePartService("Kerfuffle/Plugin");
+    const QString constraint("(exist Library)");
+    const QLatin1String basePartService("Kerfuffle/Plugin");
 
-    KService::List offers = KServiceTypeTrader::self()->query(basePartService, constraint);
+    const KService::List offers = KServiceTypeTrader::self()->query(basePartService, constraint);
     KService::List::ConstIterator it = offers.constBegin();
     KService::List::ConstIterator itEnd = offers.constEnd();
 
@@ -126,22 +122,25 @@ QStringList supportedMimeTypes()
     for (; it != itEnd; ++it) {
         KService::Ptr service = *it;
         QStringList mimeTypes = service->serviceTypes();
-        foreach(const QString& mimeType, mimeTypes)
-        if (mimeType != basePartService && !supported.contains(mimeType))
-            supported.append(mimeType);
+
+        foreach (const QString& mimeType, mimeTypes) {
+            if (mimeType != basePartService && !supported.contains(mimeType)) {
+                supported.append(mimeType);
+            }
+        }
     }
 
-    kDebug(1601) << "Returning" << supported;
+    kDebug() << "Returning" << supported;
 
     return supported;
 }
 
 QStringList supportedWriteMimeTypes()
 {
-    QString constraint("(exist Library) and ([X-KDE-Kerfuffle-ReadWrite] == true)");
-    QLatin1String basePartService("Kerfuffle/Plugin");
+    const QString constraint("(exist Library) and ([X-KDE-Kerfuffle-ReadWrite] == true)");
+    const QLatin1String basePartService("Kerfuffle/Plugin");
 
-    KService::List offers = KServiceTypeTrader::self()->query(basePartService, constraint);
+    const KService::List offers = KServiceTypeTrader::self()->query(basePartService, constraint);
     KService::List::ConstIterator it = offers.constBegin();
     KService::List::ConstIterator itEnd = offers.constEnd();
 
@@ -150,13 +149,17 @@ QStringList supportedWriteMimeTypes()
     for (; it != itEnd; ++it) {
         KService::Ptr service = *it;
         QStringList mimeTypes = service->serviceTypes();
-        foreach(const QString& mimeType, mimeTypes)
-        if (mimeType != basePartService && !supported.contains(mimeType))
-            supported.append(mimeType);
+
+        foreach (const QString& mimeType, mimeTypes) {
+            if (mimeType != basePartService && !supported.contains(mimeType)) {
+                supported.append(mimeType);
+            }
+        }
     }
 
-    kDebug(1601) << "Returning" << supported;
+    kDebug() << "Returning" << supported;
 
     return supported;
 }
+
 } // namespace Kerfuffle
