@@ -32,7 +32,7 @@ ArchiveView::ArchiveView(QWidget *parent)
         : QTreeView(parent)
         , m_mouseButtons(Qt::NoButton)
 {
-    connect(this, SIGNAL(pressed(QModelIndex)),
+    connect(this, SIGNAL(pressed(const QModelIndex&)),
             SLOT(updateMouseButtons()));
     connect(this, SIGNAL(clicked(const QModelIndex&)),
             SLOT(slotClicked(const QModelIndex&)));
@@ -40,7 +40,7 @@ ArchiveView::ArchiveView(QWidget *parent)
             SLOT(slotDoubleClicked(const QModelIndex&)));
 }
 
-// FIXME: this is a workaround taken from Dolphin until Qt-issue 176832 is resolved
+// FIXME: this is a workaround taken from Dolphin until Qt-issue 177399 is resolved
 void ArchiveView::updateMouseButtons()
 {
     m_mouseButtons = QApplication::mouseButtons();
@@ -49,7 +49,7 @@ void ArchiveView::updateMouseButtons()
 void ArchiveView::slotClicked(const QModelIndex& index)
 {
     if (KGlobalSettings::singleClick()) {
-        if (m_mouseButtons != Qt::LeftButton) // FIXME: see Qt-issue 176832
+        if (m_mouseButtons != Qt::LeftButton) // FIXME: see Qt-issue 177399
             return;
 
         // If the user is pressing shift or control, more than one item is being selected
@@ -69,7 +69,7 @@ void ArchiveView::slotDoubleClicked(const QModelIndex& index)
 
 void ArchiveView::setModel(QAbstractItemModel *model)
 {
-    kDebug(1601) ;
+    kDebug() ;
     QTreeView::setModel(model);
     setSelectionMode(QAbstractItemView::ExtendedSelection);
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
@@ -87,9 +87,12 @@ void ArchiveView::setModel(QAbstractItemModel *model)
 
 void ArchiveView::startDrag(Qt::DropActions supportedActions)
 {
-    kDebug(1601) << "Singling out the current selection...";
-    //selectionModel()->setCurrentIndex(currentIndex(), QItemSelectionModel::Clear);
-    selectionModel()->setCurrentIndex(currentIndex(), QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows);
+    //only start the drag if it's over the filename column. this allows dragging selection in
+    //tree/detail view
+    if (currentIndex().column() != 0) return;
+
+    kDebug() << "Singling out the current selection...";
+    selectionModel()->setCurrentIndex(currentIndex(), QItemSelectionModel::ClearAndSelect);
     QTreeView::startDrag(supportedActions);
 }
 
@@ -97,7 +100,7 @@ void ArchiveView::startDrag(Qt::DropActions supportedActions)
 void ArchiveView::dragEnterEvent(QDragEnterEvent * event)
 {
     //TODO: if no model, trigger some mechanism to create one automatically!
-    kDebug(1601) << event;
+    kDebug() << event;
 
     if (event->source() == this) {
         //we don't support internal drops yet.
@@ -109,7 +112,7 @@ void ArchiveView::dragEnterEvent(QDragEnterEvent * event)
 
 void ArchiveView::dropEvent(QDropEvent * event)
 {
-    kDebug(1601) << event;
+    kDebug() << event;
 
     if (event->source() == this) {
         //we don't support internal drops yet.
