@@ -47,6 +47,7 @@
 #include <KConfigGroup>
 #include <KStandardDirs>
 #include <KToggleAction>
+#include <KIO/Job>
 #include <KIO/NetAccess>
 
 #include <QCursor>
@@ -142,8 +143,7 @@ void Part::registerJob(KJob* job)
 
     //KIO::getJobTracker()->registerJob(job);
     emit busy();
-    connect(job, SIGNAL(finished(KJob*)),
-            this, SIGNAL(ready()));
+    connect(job, SIGNAL(result(KJob*)), this, SIGNAL(ready()));
 }
 
 void Part::extractSelectedFilesTo(const QString& localPath)
@@ -208,7 +208,7 @@ void Part::setupView()
 
 void Part::setupActions()
 {
-    KToggleAction *showInfoPanelAction = new KToggleAction(i18n("Show information panel"), this);
+    KToggleAction *showInfoPanelAction = new KToggleAction(i18nc("@action:inmenu", "Show information panel"), this);
     actionCollection()->addAction("show-infopanel", showInfoPanelAction);
     showInfoPanelAction->setChecked(m_splitter->sizes().at(1) > 0);
     connect(showInfoPanelAction, SIGNAL(triggered(bool)),
@@ -319,7 +319,7 @@ void Part::slotQuickExtractFiles(QAction *triggeredAction)
 
 }
 
-bool Part::isPreviewable(const QModelIndex & index)
+bool Part::isPreviewable(const QModelIndex& index) const
 {
     return index.isValid() && (!m_model->entryForIndex(index)[ IsDirectory ].toBool());
 }
@@ -340,14 +340,14 @@ bool Part::openFile()
 
     if (arguments().metaData()["createNewArchive"] == "true") {
         if (QFileInfo(localFile).exists()) {
-            int overWrite =  KMessageBox::questionYesNo(NULL, i18n("The file '%1' already exists. Would you like to open it instead?", localFile), i18n("File Exists") , KGuiItem(i18n("Open File")), KGuiItem(i18n("Cancel")));
+            int overwrite =  KMessageBox::questionYesNo(NULL, i18n("The file '%1' already exists. Would you like to open it instead?", localFile), i18nc("@title:window", "File Exists") , KGuiItem(i18n("Open File")), KGuiItem(i18n("Cancel")));
 
-            if (overWrite == KMessageBox::No)
+            if (overwrite == KMessageBox::No)
                 return false;
         }
     } else {
         if (!QFileInfo(localFile).exists()) {
-            KMessageBox::sorry(NULL, i18n("Error opening archive: the file '%1' was not found.", localFile), i18n("Error Opening Archive"));
+            KMessageBox::sorry(NULL, i18n("Error opening archive: the file '%1' was not found.", localFile), i18nc("@title:window", "Error Opening Archive"));
             return false;
         }
     }
@@ -377,7 +377,7 @@ bool Part::openFile()
         mimeComments.sort();
 
         bool ok;
-        QString item(KInputDialog::getItem(i18n("Unable to Determine Archive Type"),
+        QString item(KInputDialog::getItem(i18nc("@title:window", "Unable to Determine Archive Type"),
                                            i18n("Ark was unable to determine the archive type of the filename.\n\nPlease choose the correct archive type below."),
                                            mimeComments,
                                            0,
@@ -391,7 +391,7 @@ bool Part::openFile()
     }
 
     if (!archive) {
-        KMessageBox::sorry(NULL, i18n("Ark was not able to open the archive '%1'. No library capable of handling the file was found.", localFile), i18n("Error Opening Archive"));
+        KMessageBox::sorry(NULL, i18n("Ark was not able to open the archive '%1'. No library capable of handling the file was found.", localFile), i18nc("@title:window", "Error Opening Archive"));
         return false;
     }
 
@@ -427,7 +427,7 @@ void Part::slotLoadingFinished(KJob *job)
 
     if (job->error())
         if (arguments().metaData()["createNewArchive"] != "true")
-            KMessageBox::sorry(NULL, i18n("Reading the archive '%1' failed with the error '%2'", localFilePath(), job->errorText()), i18n("Error Opening Archive"));
+            KMessageBox::sorry(NULL, i18n("Reading the archive '%1' failed with the error '%2'", localFilePath(), job->errorText()), i18nc("@title:window", "Error Opening Archive"));
 
     m_view->sortByColumn(0, Qt::AscendingOrder);
     m_view->expandToDepth(0);
@@ -497,6 +497,9 @@ void Part::slotPreview(const QModelIndex & index)
 
 void Part::slotPreviewExtracted(KJob *job)
 {
+    // FIXME: the error checking here isn't really working
+    //        if there's an error or an overwrite dialog,
+    //        the preview dialog will be launched anyway
     if (!job->error()) {
         const ArchiveEntry& entry =
             m_model->entryForIndex(m_view->selectionModel()->currentIndex());
@@ -518,12 +521,12 @@ void Part::slotError(const QString& errorMessage, const QString& details)
     }
 }
 
-bool Part::isSingleFolderArchive()
+bool Part::isSingleFolderArchive() const
 {
     return m_model->archive()->isSingleFolderArchive();
 }
 
-QString Part::detectSubfolder()
+QString Part::detectSubfolder() const
 {
     if (!m_model) return QString();
 
@@ -635,6 +638,10 @@ void Part::slotExtractionDone(KJob* job)
 
             KRun::runUrl(destinationFolder, "inode/directory", widget());
         }
+
+        if (ArkSettings::closeAfterExtraction()) {
+           emit quit();
+        }
     }
 }
 
@@ -683,7 +690,7 @@ void Part::slotAddFiles(const QStringList& filesToAdd, const QString& path)
 void Part::slotAddFiles()
 {
     kDebug() ;
-    const QStringList filesToAdd = KFileDialog::getOpenFileNames(KUrl("kfiledialog:///ArkAddFiles"), QString(), widget(), i18n("Add Files"));
+    const QStringList filesToAdd = KFileDialog::getOpenFileNames(KUrl("kfiledialog:///ArkAddFiles"), QString(), widget(), i18nc("@title:window", "Add Files"));
 
     slotAddFiles(filesToAdd);
 }
@@ -691,7 +698,7 @@ void Part::slotAddFiles()
 void Part::slotAddDir()
 {
     kDebug() ;
-    const QString dirToAdd = KFileDialog::getExistingDirectory(KUrl("kfiledialog:///ArkAddFiles"), widget(), i18n("Add Folder"));
+    const QString dirToAdd = KFileDialog::getExistingDirectory(KUrl("kfiledialog:///ArkAddFiles"), widget(), i18nc("@title:window", "Add Folder"));
 
     if (!dirToAdd.isEmpty()) {
         slotAddFiles(QStringList() << dirToAdd);
@@ -718,7 +725,7 @@ void Part::slotDeleteFiles()
 {
     kDebug() ;
 
-    const int reallyDelete = KMessageBox::questionYesNo(NULL, i18n("Deleting these files is not undoable. Are you sure you want to do this?"), i18n("Delete files") , KGuiItem(i18n("Delete files")), KGuiItem(i18n("Cancel")));
+    const int reallyDelete = KMessageBox::questionYesNo(NULL, i18n("Deleting these files is not undoable. Are you sure you want to do this?"), i18nc("@title:window", "Delete files") , KGuiItem(i18n("Delete files")), KGuiItem(i18n("Cancel")));
 
     if (reallyDelete == KMessageBox::No)
         return;
