@@ -2,6 +2,7 @@
  * ark -- archiver for the KDE project
  *
  * Copyright (C) 2009 Harald Hvaal <haraldhv@stud.ntnu.no>
+ * Copyright (C) 2010 Raphael Kubo da Costa <kubito@gmail.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,6 +24,7 @@
 #include "kerfuffle/cliinterface.h"
 #include "kerfuffle/kerfuffle_export.h"
 
+#include <QDateTime>
 #include <QDir>
 #include <QLatin1String>
 #include <QString>
@@ -33,6 +35,7 @@ using namespace Kerfuffle;
 
 CliPlugin::CliPlugin(QObject *parent, const QVariantList & args)
         : CliInterface(parent, args)
+        , m_archiveType(ArchiveType7z)
         , m_state(ReadStateHeader)
 {
 }
@@ -73,9 +76,9 @@ ParameterList CliPlugin::parameterList() const
     return p;
 }
 
-bool CliPlugin::readListLine(const QString &line)
+bool CliPlugin::readListLine(const QString& line)
 {
-    static const QLatin1String archiveInfoDelimiter("----");
+    static const QLatin1String archiveInfoDelimiter("--");
     static const QLatin1String entryInfoDelimiter("----------");
 
     switch (m_state) {
@@ -93,7 +96,27 @@ bool CliPlugin::readListLine(const QString &line)
     case ReadStateArchiveInformation:
         if (line == entryInfoDelimiter) {
             m_state = ReadStateEntryInformation;
+        } else if (line.startsWith(QLatin1String("Type ="))) {
+            const QString type = line.mid(7).trimmed();
+            kDebug() << "Archive type: " << type;
+
+            if (type == QLatin1String("7z")) {
+                m_archiveType = ArchiveType7z;
+            } else if (type == QLatin1String("BZip2")) {
+                m_archiveType = ArchiveTypeBZip2;
+            } else if (type == QLatin1String("GZip")) {
+                m_archiveType = ArchiveTypeGZip;
+            } else if (type == QLatin1String("Tar")) {
+                m_archiveType = ArchiveTypeTar;
+            } else if (type == QLatin1String("Zip")) {
+                m_archiveType = ArchiveTypeZip;
+            } else {
+                // Should not happen
+                kWarning() << "Unsupported archive type";
+                return false;
+            }
         }
+
         break;
 
     case ReadStateEntryInformation:
@@ -106,7 +129,11 @@ bool CliPlugin::readListLine(const QString &line)
         } else if (line.startsWith(QLatin1String("Size = "))) {
             m_currentArchiveEntry[ Size ] = line.mid(7).trimmed();
         } else if (line.startsWith(QLatin1String("Packed Size = "))) {
-            m_currentArchiveEntry[ CompressedSize ] = line.mid(14).trimmed();
+            // #236696: 7z files only show a single Packed Size value
+            //          corresponding to the whole archive.
+            if (m_archiveType != ArchiveType7z) {
+                m_currentArchiveEntry[CompressedSize] = line.mid(14).trimmed();
+            }
         } else if (line.startsWith(QLatin1String("Modified = "))) {
             m_currentArchiveEntry[ Timestamp ] =
                 QDateTime::fromString(line.mid(11).trimmed(),
