@@ -65,19 +65,27 @@ bool LibArchiveInterface::list()
     int result;
 
     arch = archive_read_new();
-    if (!arch)
+    if (!arch) {
         return false;
+    }
 
     result = archive_read_support_compression_all(arch);
-    if (result != ARCHIVE_OK) return false;
+    if (result != ARCHIVE_OK) {
+        archive_read_finish(arch);
+        return false;
+    }
 
     result = archive_read_support_format_all(arch);
-    if (result != ARCHIVE_OK) return false;
+    if (result != ARCHIVE_OK) {
+        archive_read_finish(arch);
+        return false;
+    }
 
     result = archive_read_open_filename(arch, QFile::encodeName(filename()), 10240);
 
     if (result != ARCHIVE_OK) {
         error(i18n("Could not open the file '%1', libarchive cannot handle it.", filename()), QString());
+        archive_read_finish(arch);
         return false;
     }
 
@@ -85,7 +93,10 @@ bool LibArchiveInterface::list()
     m_extractedFilesSize = 0;
 
     while ((result = archive_read_next_header(arch, &aentry)) == ARCHIVE_OK) {
-        if (!m_emitNoEntries) emitEntryFromArchiveEntry(aentry);
+        if (!m_emitNoEntries) {
+            emitEntryFromArchiveEntry(aentry);
+        }
+
         m_extractedFilesSize += (qlonglong) archive_entry_size(aentry);
 
         m_cachedArchiveEntryCount++;
@@ -94,6 +105,7 @@ bool LibArchiveInterface::list()
 
     if (result != ARCHIVE_EOF) {
         error(i18n("The archive reading failed with message: %1", archive_error_string(arch)));
+        archive_read_finish(arch);
         return false;
     }
 
@@ -112,8 +124,6 @@ bool LibArchiveInterface::copyFiles(const QList<QVariant> & files, const QString
     const bool extractAll = files.isEmpty();
     const bool preservePaths = options.value("PreservePaths").toBool();
 
-    //TODO: don't leak these if the extraction fails with an error in the
-    //middle
     struct archive *arch, *writer;
     struct archive_entry *entry;
 
@@ -128,18 +138,24 @@ bool LibArchiveInterface::copyFiles(const QList<QVariant> & files, const QString
         return false;
     }
 
-    writer = archive_write_disk_new();
-    archive_write_disk_set_options(writer, extractionFlags());
-
     archive_read_support_compression_all(arch);
     archive_read_support_format_all(arch);
-    int res = archive_read_open_filename(arch, QFile::encodeName(filename()), 10240);
 
-    if (res != ARCHIVE_OK) {
-        error(i18n("Unable to open the file '%1', libarchive cannot handle it.", filename())) ;
+    if (archive_read_open_filename(arch, QFile::encodeName(filename()), 10240) != ARCHIVE_OK) {
+        error(i18n("Unable to open the file '%1', libarchive cannot handle it.",
+                   filename()));
+        archive_read_finish(arch);
         return false;
     }
 
+    writer = archive_write_disk_new();
+    if (!writer) {
+        archive_read_finish(arch);
+        return false;
+    }
+
+    archive_write_disk_set_options(writer, extractionFlags());
+
     int entryNr = 0, totalCount = 0;
     if (extractAll) {
         if (!m_cachedArchiveEntryCount) {
@@ -152,15 +168,18 @@ bool LibArchiveInterface::copyFiles(const QList<QVariant> & files, const QString
             m_emitNoEntries = false;
         }
         totalCount = m_cachedArchiveEntryCount;
-    } else
+    } else {
         totalCount = files.size();
+    }
+
     m_currentExtractedFilesSize = 0;
 
     bool overwriteAll = false; // Whether to overwrite all files
     bool skipAll = false; // Whether to skip all files
 
     while (archive_read_next_header(arch, &entry) == ARCHIVE_OK) {
-        //retry with renamed entry, fire an overwrite query again if the new entry also exists
+        // retry with renamed entry, fire an overwrite query again
+        // if the new entry also exists
     retry:
         const bool entryIsDir = S_ISDIR(archive_entry_mode(entry));
 
@@ -177,6 +196,10 @@ bool LibArchiveInterface::copyFiles(const QList<QVariant> & files, const QString
             //for now we just can't handle absolute filenames in a tar archive.
             //TODO: find out what to do here!!
             error(i18n("This archive contains archive entries with absolute paths, which are not yet supported by ark."));
+
+            archive_read_finish(arch);
+            archive_write_finish(arch);
+
             return false;
         }
 
@@ -322,6 +345,7 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
         ret = archive_read_open_filename(arch_reader, QFile::encodeName(filename()), 10240);
         if (ret != ARCHIVE_OK) {
             error(i18n("The source file could not be read."));
+            archive_read_finish(arch_reader);
             return false;
         }
     }
@@ -348,11 +372,11 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
             kDebug() << "Detected xz compression for new file";
             ret = archive_write_set_compression_xz(arch_writer);
 #endif
-#ifdef HAVE_LIBARCHIVE_LZMA_SUPPORT	    
+#ifdef HAVE_LIBARCHIVE_LZMA_SUPPORT
         } else if (filename().right(4).toUpper() == "LZMA") {
             kDebug() << "Detected lzma compression for new file";
             ret = archive_write_set_compression_lzma(arch_writer);
-#endif	    
+#endif
         } else if (filename().right(3).toUpper() == "TAR") {
             kDebug() << "Detected no compression for new file (pure tar)";
             ret = archive_write_set_compression_none(arch_writer);
@@ -363,11 +387,9 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
 
         if (ret != ARCHIVE_OK) {
             error(i18n("Setting compression failed with the error '%1'", QString(archive_error_string(arch_writer))));
-            return false;
-        }
 
-        if (ret != ARCHIVE_OK) {
-            error(i18n("Setting format failed with the error '%1'", QString(archive_error_string(arch_writer))));
+            archive_write_finish(arch_writer);
+
             return false;
         }
     } else {
@@ -387,16 +409,25 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
         case ARCHIVE_COMPRESSION_LZMA:
             ret = archive_write_set_compression_lzma(arch_writer);
             break;
-#endif	    
+#endif
         case ARCHIVE_COMPRESSION_NONE:
             ret = archive_write_set_compression_none(arch_writer);
             break;
         default:
             error(i18n("The compression type '%1' is not supported by Ark.", QString(archive_compression_name(arch_reader))));
+
+            archive_read_finish(arch_reader);
+            archive_write_finish(arch_writer);
+
             return false;
         }
+
         if (ret != ARCHIVE_OK) {
             error(i18n("Setting compression failed with the error '%1'", QString(archive_error_string(arch_writer))));
+
+            archive_read_finish(arch_reader);
+            archive_write_finish(arch_writer);
+
             return false;
         }
     }
@@ -404,6 +435,12 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
     ret = archive_write_open_filename(arch_writer, QFile::encodeName(tempFilename));
     if (ret != ARCHIVE_OK) {
         error(i18n("Opening the archive for writing failed with error message '%1'", QString(archive_error_string(arch_writer))));
+
+        if (!creatingNewFile) {
+            archive_read_finish(arch_reader);
+        }
+        archive_write_finish(arch_writer);
+
         return false;
     }
 
@@ -415,8 +452,12 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
 
         success = writeFile(selectedFile, arch_writer, entry);
 
-        if (!success)
+        if (!success) {
+            archive_read_finish(arch_reader);
+            archive_write_finish(arch_writer);
+
             return false;
+        }
 
         if (QFileInfo(selectedFile).isDir()) {
             QDirIterator it(selectedFile, QDir::AllEntries | QDir::Readable | QDir::Hidden | QDir::NoDotAndDotDot, QDirIterator::Subdirectories);
@@ -429,8 +470,14 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
                                     (it.fileInfo().isDir() ? "/" : "")
                                     , arch_writer, entry);
 
-                if (!success)
+                if (!success) {
+                    if (!creatingNewFile) {
+                        archive_read_finish(arch_reader);
+                    }
+                    archive_write_finish(arch_writer);
+
                     return false;
+                }
             }
         }
     }
@@ -452,6 +499,10 @@ bool LibArchiveInterface::addFiles(const QStringList & files, const CompressionO
                 copyData(arch_reader, arch_writer, false);
             else {
                 kDebug() << "Writing header failed with error code " << header_response;
+
+                archive_read_finish(arch_reader);
+                archive_write_finish(arch_writer);
+
                 return false;
             }
 
@@ -495,6 +546,7 @@ bool LibArchiveInterface::deleteFiles(const QList<QVariant> & files)
     ret = archive_read_open_filename(arch_reader, QFile::encodeName(filename()), 10240);
     if (ret != ARCHIVE_OK) {
         error(i18n("The source file could not be read."));
+        archive_read_finish(arch_reader);
         return false;
     }
 
@@ -502,6 +554,7 @@ bool LibArchiveInterface::deleteFiles(const QList<QVariant> & files)
     arch_writer = archive_write_new();
     if (!arch_writer) {
         error(i18n("The archive writer could not be initialized."));
+        archive_read_finish(arch_reader);
         return false;
     }
 
@@ -524,23 +577,35 @@ bool LibArchiveInterface::deleteFiles(const QList<QVariant> & files)
     case ARCHIVE_COMPRESSION_LZMA:
         ret = archive_write_set_compression_lzma(arch_writer);
         break;
-#endif	
+#endif
     case ARCHIVE_COMPRESSION_NONE:
         ret = archive_write_set_compression_none(arch_writer);
         break;
     default:
         error(i18n("The compression type '%1' is not supported by Ark.", QString(archive_compression_name(arch_reader))));
+
+        archive_read_finish(arch_reader);
+        archive_write_finish(arch_writer);
+
         return false;
     }
 
     if (ret != ARCHIVE_OK) {
         error(i18n("Setting compression failed with the error '%1'", QString(archive_error_string(arch_writer))));
+
+        archive_read_finish(arch_reader);
+        archive_write_finish(arch_writer);
+
         return false;
     }
 
     ret = archive_write_open_filename(arch_writer, QFile::encodeName(tempFilename));
     if (ret != ARCHIVE_OK) {
         error(i18n("Opening the archive for writing failed with error message '%1'", QString(archive_error_string(arch_writer))));
+
+        archive_read_finish(arch_reader);
+        archive_write_finish(arch_writer);
+
         return false;
     }
 
@@ -563,14 +628,17 @@ bool LibArchiveInterface::deleteFiles(const QList<QVariant> & files)
             copyData(arch_reader, arch_writer, false);
         else {
             kDebug() << "Writing header failed with error code " << header_response;
+
+            archive_read_finish(arch_reader);
+            archive_write_finish(arch_writer);
+
             return false;
         }
 
         archive_entry_clear(entry);
     }
 
-    ret = archive_write_finish(arch_writer);
-
+    archive_write_finish(arch_writer);
     archive_read_finish(arch_reader);
 
     //everything seems OK, so we remove the source file and replace it with
