@@ -1,3 +1,8 @@
+/*
+ * Copyright (C) 2006,2007 Jimmy Gilles <jimmygilles@gmail.com>
+ * Copyright (C) 2007-2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ */
+
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -32,15 +37,13 @@ bool KgpgKeySignPrivate::operator==(const KgpgKeySignPrivate &other) const
 }
 
 KgpgKeySign::KgpgKeySign()
-           : QObject()
+    : d(new  KgpgKeySignPrivate)
 {
-    d = new KgpgKeySignPrivate;
     d->gpgsignrevocation = false;
     d->gpgsignlocal = false;
 }
 
 KgpgKeySign::KgpgKeySign(const KgpgKeySign &other)
-           : QObject()
 {
     d = other.d;
 }
@@ -65,12 +68,12 @@ void KgpgKeySign::setComment(const QString &comment)
     d->gpgsigncomment = comment;
 }
 
-void KgpgKeySign::setExpiration(const QDate &date)
+void KgpgKeySign::setExpiration(const QDateTime &date)
 {
     d->gpgsignexpiration = date;
 }
 
-void KgpgKeySign::setCreation(const QDate &date)
+void KgpgKeySign::setCreation(const QDateTime &date)
 {
     d->gpgsigncreation = date;
 }
@@ -115,12 +118,12 @@ bool KgpgKeySign::unlimited() const
     return d->gpgsignexpiration.isNull();
 }
 
-QDate KgpgKeySign::expirationDate() const
+QDateTime KgpgKeySign::expirationDate() const
 {
     return d->gpgsignexpiration;
 }
 
-QDate KgpgKeySign::creationDate() const
+QDateTime KgpgKeySign::creationDate() const
 {
     return d->gpgsigncreation;
 }
@@ -135,16 +138,6 @@ bool KgpgKeySign::revocation() const
     return d->gpgsignrevocation;
 }
 
-QString KgpgKeySign::expiration() const
-{
-    return KgpgKey::expiration(d->gpgsignexpiration);
-}
-
-QString KgpgKeySign::creation() const
-{
-    return Convert::toString(d->gpgsigncreation);
-}
-
 bool KgpgKeySign::operator==(const KgpgKeySign &other) const
 {
     if (d == other.d) return true;
@@ -172,13 +165,11 @@ bool KgpgKeyUatPrivate::operator==(const KgpgKeyUatPrivate &other) const
 }
 
 KgpgKeyUat::KgpgKeyUat()
-          : QObject()
+    : d(new  KgpgKeyUatPrivate)
 {
-    d = new KgpgKeyUatPrivate;
 }
 
 KgpgKeyUat::KgpgKeyUat(const KgpgKeyUat &other)
-          : QObject()
 {
     d = other.d;
 }
@@ -188,7 +179,7 @@ void KgpgKeyUat::setId(const QString &id)
     d->gpguatid = id;
 }
 
-void KgpgKeyUat::setCreation(const QDate &date)
+void KgpgKeyUat::setCreation(const QDateTime &date)
 {
     d->gpguatcreation = date;
 }
@@ -198,16 +189,11 @@ QString KgpgKeyUat::id() const
     return d->gpguatid;
 }
 
-QDate KgpgKeyUat::creationDate() const
+QDateTime KgpgKeyUat::creationDate() const
 {
     return d->gpguatcreation;
 }
 
-QString KgpgKeyUat::creation() const
-{
-    return Convert::toString(d->gpguatcreation);
-}
-
 void KgpgKeyUat::addSign(const KgpgKeySign &sign)
 {
     d->gpgsignlist << sign;
@@ -249,15 +235,13 @@ bool KgpgKeyUidPrivate::operator==(const KgpgKeyUidPrivate &other) const
 }
 
 KgpgKeyUid::KgpgKeyUid()
-          : QObject()
+    : d(new  KgpgKeyUidPrivate)
 {
-    d = new KgpgKeyUidPrivate;
     d->gpguidvalid = false;
     d->gpguidindex = 0;
 }
 
 KgpgKeyUid::KgpgKeyUid(const KgpgKeyUid &other)
-          : QObject()
 {
     d = other.d;
 }
@@ -365,15 +349,13 @@ bool KgpgKeySubPrivate::operator==(const KgpgKeySubPrivate &other) const
 }
 
 KgpgKeySub::KgpgKeySub()
-          : QObject()
+    : d(new  KgpgKeySubPrivate)
 {
-    d = new KgpgKeySubPrivate;
     d->gpgsubsize = 0;
     d->gpgsubvalid = false;
 }
 
 KgpgKeySub::KgpgKeySub(const KgpgKeySub &other)
-          : QObject()
 {
     d = other.d;
 }
@@ -388,12 +370,12 @@ void KgpgKeySub::setSize(const uint &size)
     d->gpgsubsize = size;
 }
 
-void KgpgKeySub::setExpiration(const QDate &date)
+void KgpgKeySub::setExpiration(const QDateTime &date)
 {
     d->gpgsubexpiration = date;
 }
 
-void KgpgKeySub::setCreation(const QDate &date)
+void KgpgKeySub::setCreation(const QDateTime &date)
 {
     d->gpgsubcreation = date;
 }
@@ -433,12 +415,12 @@ bool KgpgKeySub::unlimited() const
     return d->gpgsubexpiration.isNull();
 }
 
-QDate KgpgKeySub::expirationDate() const
+QDateTime KgpgKeySub::expirationDate() const
 {
     return d->gpgsubexpiration;
 }
 
-QDate KgpgKeySub::creationDate() const
+QDateTime KgpgKeySub::creationDate() const
 {
     return d->gpgsubcreation;
 }
@@ -463,16 +445,6 @@ KgpgSubKeyType KgpgKeySub::type() const
     return d->gpgsubtype;
 }
 
-QString KgpgKeySub::creation() const
-{
-    return Convert::toString(d->gpgsubcreation);
-}
-
-QString KgpgKeySub::expiration() const
-{
-    return KgpgKey::expiration(d->gpgsubexpiration);
-}
-
 void KgpgKeySub::addSign(const KgpgKeySign &sign)
 {
     d->gpgsignlist << sign;
@@ -501,18 +473,15 @@ KgpgKeySub& KgpgKeySub::operator=(const KgpgKeySub &other)
 
 //BEGIN Key
 
-QString KgpgKey::expiration(const QDate &date)
-{
-    if (date.isNull())
-        return i18nc("Unlimited key lifetime", "Unlimited");
-    return Convert::toString(date);
-}
-
 KgpgKeyPrivate::KgpgKeyPrivate()
+    : gpgkeysecret(false),
+    gpgkeyvalid(false),
+    gpgkeysize(0),
+    gpgkeyalgo(ALGO_UNKNOWN),
+    gpguatlist(new KgpgKeyUatList()),
+    gpguidlist(new KgpgKeyUidList()),
+    gpgsublist(new KgpgKeySubList())
 {
-    gpguatlist = new KgpgKeyUatList;
-    gpguidlist = new KgpgKeyUidList;
-    gpgsublist = new KgpgKeySubList;
 }
 
 bool KgpgKeyPrivate::operator==(const KgpgKeyPrivate &other) const
@@ -537,17 +506,11 @@ bool KgpgKeyPrivate::operator==(const KgpgKeyPrivate &other) const
 }
 
 KgpgKey::KgpgKey()
-       : QObject()
+    : d(new KgpgKeyPrivate())
 {
-    d = new KgpgKeyPrivate;
-    d->gpgkeyalgo = ALGO_UNKNOWN;
-    d->gpgkeyvalid = false;
-    d->gpgkeysecret = false;
-    d->gpgkeysize = 0;
 }
 
 KgpgKey::KgpgKey(const KgpgKey &other)
-       : QObject()
 {
     d = other.d;
 }
@@ -597,12 +560,12 @@ void KgpgKey::setTrust(const KgpgKeyTrust &trust)
     d->gpgkeytrust = trust;
 }
 
-void KgpgKey::setCreation(const QDate &date)
+void KgpgKey::setCreation(const QDateTime &date)
 {
     d->gpgkeycreation = date;
 }
 
-void KgpgKey::setExpiration(const QDate &date)
+void KgpgKey::setExpiration(const QDateTime &date)
 {
     d->gpgkeyexpiration = date;
 }
@@ -689,12 +652,12 @@ KgpgKeyTrust KgpgKey::trust() const
     return d->gpgkeytrust;
 }
 
-QDate KgpgKey::creationDate() const
+QDateTime KgpgKey::creationDate() const
 {
     return d->gpgkeycreation;
 }
 
-QDate KgpgKey::expirationDate() const
+QDateTime KgpgKey::expirationDate() const
 {
     return d->gpgkeyexpiration;
 }
@@ -721,16 +684,6 @@ KgpgKeyAlgo KgpgKey::encryptionAlgorithm() const
 	return ALGO_UNKNOWN;
 }
 
-QString KgpgKey::creation() const
-{
-    return Convert::toString(d->gpgkeycreation);
-}
-
-QString KgpgKey::expiration() const
-{
-    return expiration(d->gpgkeyexpiration);
-}
-
 QStringList KgpgKey::photoList() const
 {
     QStringList result;
