@@ -53,8 +53,9 @@
 #include "sourceselect.h"
 #include "kgpgtextedit.h"
 #include "kgpg.h"
-#include "kgpg_interface.h"
 #include "kgpgtextinterface.h"
+#include "kgpgkeyservergettransaction.h"
+#include "keysmanager.h"
 
 class KgpgView : public QWidget {
 public:
@@ -73,12 +74,14 @@ KgpgView::KgpgView(QWidget *parent, KgpgTextEdit *editor, KToolBar *toolbar)
 }
 
 KgpgEditor::KgpgEditor(KeysManager *parent, KGpgItemModel *model, Qt::WFlags f)
-          : KXmlGuiWindow(0, f),
-	  m_editor(new KgpgTextEdit(this, model)),
-	  m_recentfiles(NULL),
-	  m_find(0),
-	  m_model(model),
-	  m_parent(parent)
+	: KXmlGuiWindow(0, f),
+	m_editor(new KgpgTextEdit(this, model, parent)),
+	m_recentfiles(NULL),
+	m_find(0),
+	m_textchanged(false),
+	m_emptytext(true),
+	m_model(model),
+	m_parent(parent)
 {
     // call inits to invoke all other construction parts
     initActions();
@@ -91,8 +94,6 @@ KgpgEditor::KgpgEditor(KeysManager *parent, KGpgItemModel *model, Qt::WFlags f)
     m_editundo->setEnabled(false);
     m_editcopy->setEnabled(false);
     m_editcut->setEnabled(false);
-    m_textchanged = false;
-    m_emptytext = true;
 
     setObjectName("editor");
     slotSetFont(KGpgSettings::font());
@@ -336,44 +337,39 @@ bool KgpgEditor::slotFileSave()
 
 bool KgpgEditor::slotFileSaveAs()
 {
-    KEncodingFileDialog::Result saveResult;
-    saveResult = KEncodingFileDialog::getSaveUrlAndEncoding(QString(), QString(), QString(), this);
-    KUrl url;
+	KEncodingFileDialog::Result saveResult;
+	saveResult = KEncodingFileDialog::getSaveUrlAndEncoding(QString(), QString(), QString(), this);
+	KUrl url;
 
-    if (!saveResult.URLs.empty())
-        url = saveResult.URLs.first();
+	if (!saveResult.URLs.empty())
+		url = saveResult.URLs.first();
 
-    if(!url.isEmpty())
-    {
-        const QString selectedEncoding = saveResult.encoding;
-        if (url.isLocalFile())
-        {
-            QString filn = url.path();
-            QFile f(filn);
-            if (f.exists())
-            {
-                QString message = i18n("Overwrite existing file %1?", url.fileName());
-                int result = KMessageBox::warningContinueCancel(this, QString(message), QString(), KStandardGuiItem::overwrite());
-                if (result == KMessageBox::Cancel)
-                    return false;
-            }
-            f.close();
-        }
-        else
-        if (KIO::NetAccess::exists(url, KIO::NetAccess::DestinationSide, this))
-        {
-            QString message = i18n("Overwrite existing file %1?", url.fileName());
-            int result = KMessageBox::warningContinueCancel(this, QString(message), QString(), KStandardGuiItem::overwrite());
-            if (result == KMessageBox::Cancel)
-                return false;
-        }
+	if(!url.isEmpty()) {
+		const QString selectedEncoding = saveResult.encoding;
+		if (url.isLocalFile()) {
+			QString filn = url.path();
+			QFile f(url.path());
+			if (f.exists()) {
+				const QString message = i18n("Overwrite existing file %1?", url.fileName());
+				int result = KMessageBox::warningContinueCancel(this, message, QString(), KStandardGuiItem::overwrite());
+				if (result == KMessageBox::Cancel)
+					return false;
+			}
+			f.close();
+		} else if (KIO::NetAccess::exists(url, KIO::NetAccess::DestinationSide, this)) {
+			const QString message = i18n("Overwrite existing file %1?", url.fileName());
+			int result = KMessageBox::warningContinueCancel(this, message, QString(), KStandardGuiItem::overwrite());
+			if (result == KMessageBox::Cancel)
+				return false;
+		}
 
-        m_docname = url;
-        m_textencoding = selectedEncoding;
-        slotFileSave();
-        return true;
-    }
-    return false;
+		m_docname = url;
+		m_textencoding = selectedEncoding;
+		slotFileSave();
+		return true;
+	}
+
+	return false;
 }
 
 void KgpgEditor::slotFilePrint()
@@ -536,13 +532,19 @@ void KgpgEditor::slotFilePreDec()
         }
 
         KgpgLibrary *lib = new KgpgLibrary(this);
-        connect(lib, SIGNAL(importOver(KgpgLibrary *, QStringList)), SLOT(slotRefreshImported(KgpgLibrary *, QStringList)));
+	connect(lib, SIGNAL(decryptionOver(KUrl)), SLOT(slotLibraryDone()));
         lib->slotFileDec(url, KUrl(newname), m_customdecrypt);
     }
     else
         openEncryptedDocumentFile(url);
 }
 
+void
+KgpgEditor::slotLibraryDone()
+{
+	sender()->deleteLater();
+}
+
 void
 KgpgEditor::slotRefreshImported(KgpgLibrary *lib, const QStringList &keys)
 {
@@ -552,10 +554,8 @@ KgpgEditor::slotRefreshImported(KgpgLibrary *lib, const QStringList &keys)
 
 void KgpgEditor::slotKeyManager()
 {
-    OrgKdeKgpgKeyInterface kgpg("org.kde.kgpg", "/KeyInterface",QDBusConnection::sessionBus());
-    QDBusReply<void> reply =kgpg.showKeyManager();
-    if (!reply.isValid())
-        kDebug(2100) << "there was some error using dbus." ;
+	m_parent->show();
+	m_parent->raise();
 }
 
 void KgpgEditor::slotFileClose()
@@ -648,14 +648,14 @@ void KgpgEditor::slotSignFile(const KUrl &url)
         Options << "--detach-sign";
 
         KGpgTextInterface *interface = new KGpgTextInterface();
-        //TODO connect(interface, SIGNAL(...), this, SLOT(slotSignFileFin(KgpgInterface *interface)));
+        //TODO connect(interface, SIGNAL(...), this, SLOT(slotSignFileFin()));
         interface->signFiles(signKeyID, url, Options);
     }
 }
 
-void KgpgEditor::slotSignFileFin(KgpgInterface *interface)
+void KgpgEditor::slotSignFileFin()
 {
-    delete interface;
+	sender()->deleteLater();
 }
 
 void KgpgEditor::slotPreVerifyFile()
@@ -684,37 +684,50 @@ void KgpgEditor::slotVerifyFile(const KUrl &url)
         }
 
         // pipe gpg command
-        KGpgTextInterface *interface = new KGpgTextInterface();
+        KGpgTextInterface *interface = new KGpgTextInterface(this);
+        connect(interface, SIGNAL(verifyquerykey(QString)), SLOT(importSignatureKey(QString)));
+        connect(interface, SIGNAL(verifyfinished()), SLOT(slotVerifyFinished()));
         interface->KgpgVerifyFile(url, KUrl(sigfile));
-        connect(interface, SIGNAL(verifyquerykey(QString)), this, SLOT(importSignatureKey(QString)));
     }
 }
 
 void KgpgEditor::slotCheckMd5()
 {
-    // display md5 sum for a chosen file
-    KUrl url = KFileDialog::getOpenUrl(KUrl(), i18n("*|All Files"), this, i18n("Open File to Verify"));
-    if (!url.isEmpty())
-    {
-        QPointer<Md5Widget> mdwidget = new Md5Widget(this, url);
-        mdwidget->exec();
-        delete mdwidget;
-    }
+	// display md5 sum for a chosen file
+	KUrl url = KFileDialog::getOpenUrl(KUrl(), i18n("*|All Files"), this, i18n("Open File to Verify"));
+	if (!url.isEmpty()) {
+		QPointer<Md5Widget> mdwidget = new Md5Widget(this, url);
+		mdwidget->exec();
+		delete mdwidget;
+	}
 }
 
 void KgpgEditor::importSignatureKey(const QString &id)
 {
-    KeyServer *kser = new KeyServer(0, m_model);
-    kser->slotSetText(id);
-    kser->slotImport();
+	KeyServer *ks = new KeyServer(this);
+
+	connect(ks, SIGNAL(importFinished(QStringList)), SLOT(slotDownloadKeysFinished(QStringList)));
+	connect(ks, SIGNAL(importFailed()), ks, SLOT(deleteLater()));
+
+	ks->startImport(QStringList(id), QString(), qgetenv("http_proxy"));
+}
+
+void KgpgEditor::slotDownloadKeysFinished(QStringList ids)
+{
+	m_parent->refreshKeys(ids);
+
+	sender()->deleteLater();
+}
+
+void
+KgpgEditor::slotVerifyFinished()
+{
+	sender()->deleteLater();
 }
 
 void KgpgEditor::slotOptions()
 {
-    OrgKdeKgpgKeyInterface kgpg("org.kde.kgpg", "/KeyInterface",QDBusConnection::sessionBus());
-    QDBusReply<void> reply =kgpg.showOptions();
-    if (!reply.isValid())
-        kDebug(2100) << "there was some error using dbus." ;
+	m_parent->showOptions();
 }
 
 void KgpgEditor::modified()
@@ -733,27 +746,27 @@ void KgpgEditor::modified()
 
 void KgpgEditor::slotUndoAvailable(const bool &v)
 {
-    m_editundo->setEnabled(v);
+	m_editundo->setEnabled(v);
 }
 
 void KgpgEditor::slotRedoAvailable(const bool &v)
 {
-    m_editredo->setEnabled(v);
+	m_editredo->setEnabled(v);
 }
 
 void KgpgEditor::slotCopyAvailable(const bool &v)
 {
-    m_editcopy->setEnabled(v);
-    m_editcut->setEnabled(v);
+	m_editcopy->setEnabled(v);
+	m_editcut->setEnabled(v);
 }
 
 void KgpgEditor::newText()
 {
-    m_textchanged = false;
-    m_emptytext = true;
-    m_docname.clear();
-    setCaption(i18n("Untitled"), false);
-    slotResetEncoding(false);
+	m_textchanged = false;
+	m_emptytext = true;
+	m_docname.clear();
+	setCaption(i18n("Untitled"), false);
+	slotResetEncoding(false);
 }
 
 #include "kgpgeditor.moc"
