@@ -36,28 +36,38 @@
 #include "images.h"
 #include "kgpgsettings.h"
 
+#include "keylistproxymodel.h"
+#include "kgpgitemmodel.h"
+#include "kgpginterface.h"
+
 // #include "conf_decryption.h"
 #include "conf_encryption.h"
 
 using namespace KgpgCore;
 
 //   main window
-kgpgOptions::kgpgOptions(QWidget *parent, const char *name)
-           : KConfigDialog(parent, name, KGpgSettings::self()),
+kgpgOptions::kgpgOptions(QWidget *parent, KGpgItemModel *model)
+           : KConfigDialog(parent, "settings", KGpgSettings::self()),
 	   m_config(new KConfig("kgpgrc", KConfig::SimpleConfig)),
 	   m_page1(new Encryption()),
 	   m_page2(new Decryption()),
 	   m_page3(new UIConf()),
 	   m_page4(new GPGConf()),
 	   m_page6(new ServerConf()),
-	   m_page7(new MiscConf())
+	   m_page7(new MiscConf()),
+	   m_model(model),
+	   m_combomodel(new KeyListProxyModel(this, KeyListProxyModel::SingleColumnIdFirst))
 {
+	m_combomodel->setKeyModel(m_model);
+	m_combomodel->setTrustFilter(KgpgCore::TRUST_MARGINAL);
+	m_combomodel->sort(0);
+
 	// Initialize the default server and the default server list.
 	defaultKeyServer = "hkp://wwwkeys.pgp.net";
 	defaultServerList << defaultKeyServer << "hkp://search.keyserver.net" << "hkp://pgp.dtype.org";
 	defaultServerList << "hkp://wwwkeys.us.pgp.net" << "hkp://subkeys.pgp.net";
 
-	// Read the default keyserver from the gnupg settings.
+	// Read the default keyserver from the GnuPG settings.
 	keyServer = KgpgInterface::getGpgSetting("keyserver", KGpgSettings::gpgConfigPath());
 
 	// Read the servers stored in kgpgrc
@@ -73,6 +83,7 @@ kgpgOptions::kgpgOptions(QWidget *parent, const char *name)
 
 	m_showsystray = KGpgSettings::showSystray();
 	m_trayaction = KGpgSettings::leftClick();
+	m_mailUats = KGpgSettings::mailUats();
 
 	QVBoxLayout *fontlayout = new QVBoxLayout(m_page3->tabWidget3->widget(1));
 	fontlayout->setSpacing(spacingHint());
@@ -91,7 +102,7 @@ kgpgOptions::kgpgOptions(QWidget *parent, const char *name)
 	addPage(m_page7, i18n("Misc"), "preferences-other");
 
 	// The following widgets are managed manually.
-		connect(m_page1->encrypt_to_always, SIGNAL(toggled(bool)), this, SLOT(slotChangeEncryptTo()));
+	connect(m_page1->encrypt_to_always, SIGNAL(toggled(bool)), this, SLOT(slotChangeEncryptTo()));
 	connect(m_page4->changeHome, SIGNAL(clicked()), this, SLOT(slotChangeHome()));
 	connect(m_page6->server_add, SIGNAL(clicked()), this, SLOT(slotAddKeyServer()));
 	connect(m_page6->server_del, SIGNAL(clicked()), this, SLOT(slotDelKeyServer()));
@@ -136,11 +147,11 @@ void kgpgOptions::slotChangeHome()
 		if (!QFile(gpgHome + confPath).exists()) {
 			// Try to create config File by running gpg once
 			if (KMessageBox::Yes == KMessageBox::questionYesNo(this,
-					i18n("No configuration file was found in the selected location.\nDo you want to create it now ?\n\nWithout configuration file, neither KGpg nor Gnupg will work properly."),
+					i18n("No configuration file was found in the selected location.\nDo you want to create it now?\n\nWithout a configuration file, neither KGpg nor GnuPG will work properly."),
 					i18n("No Configuration File Found"),
 					KGuiItem(i18n("Create")),
 					KGuiItem(i18n("Ignore")))) {
-				// start gnupg so that it will create a config file
+				// start GnuPG so that it will create a config file
 				QString gpgbin = m_page4->gpg_bin_path->text();
 				if (!QFile::exists(gpgbin))
 					gpgbin = "gpg";
@@ -242,7 +253,7 @@ void kgpgOptions::slotEditKeyServer(QListWidgetItem *cur)
 	bool isDefault = false;
 	if (oldServer.contains(' ')) {
 		isDefault = true;
-		oldServer = oldServer.section(" ", 0, 0);
+		oldServer = oldServer.section(' ', 0, 0);
 	}
 
 	QString newServer(KInputDialog::getText(i18n("Edit Key Server"), i18n("Server URL:"), oldServer).simplified());
@@ -292,11 +303,36 @@ void kgpgOptions::updateWidgets()
 
 	listKeys();
 	fileEncryptionKey = KGpgSettings::fileEncryptionKey();
-	if (!fileEncryptionKey.isEmpty())
-		m_page1->file_key->setCurrentItem(fileEncryptionKey);
+	// the contents are totally mess. There were key id, name and email stored
+	// try to extract the key id, that's the only thing we really need
+	if (!fileEncryptionKey.isEmpty()) {
+		int idpos = m_page1->file_key->findText(fileEncryptionKey);
+		if (idpos == -1) {
+			idpos = fileEncryptionKey.indexOf(QRegExp("([0-9A-Fa-F]{8})+"));
+			if (idpos >= 0) {
+				QString fileId = fileEncryptionKey.mid(idpos);
+				idpos = fileId.indexOf(QRegExp("[^a-fA-F0-9]"));
+				if (idpos >= 0) {
+					fileId = fileId.left(idpos);
+					fileId.chop(fileId.length() % 8);
+				}
 
-	if (!alwaysKeyName.isEmpty())
-		m_page1->always_key->setCurrentItem(alwaysKeyName);
+				KGpgKeyNode *anode = m_combomodel->getModel()->findKeyNode(fileId);
+
+				if (anode != NULL)
+					idpos = m_combomodel->nodeIndex(anode).row();
+			}
+		}
+		m_page1->file_key->setCurrentIndex(idpos);
+	}
+
+	if (!alwaysKeyID.isEmpty()) {
+		KGpgKeyNode *anode = m_combomodel->getModel()->findKeyNode(alwaysKeyID);
+		if (anode != NULL) {
+			const QModelIndex midx(m_combomodel->nodeIndex(anode));
+			m_page1->always_key->setCurrentIndex(midx.row());
+		}
+	}
 
 	gpgConfigPath = KGpgSettings::gpgConfigPath();
 	m_page4->gpg_conf_path->setText(KUrl::fromPath(gpgConfigPath).fileName());
@@ -355,7 +391,7 @@ void kgpgOptions::updateSettings()
 
 	// save selected keys for file encryption & always encrypt with
 	if (m_page1->kcfg_EncryptFilesTo->isChecked())
-		fileEncryptionKey = m_page1->file_key->currentText();
+		fileEncryptionKey = m_page1->file_key->itemData(m_page1->file_key->currentIndex(), Qt::ToolTipRole).toString();
 	else
 		fileEncryptionKey.clear();
 
@@ -365,7 +401,7 @@ void kgpgOptions::updateSettings()
 	m_encrypttoalways = m_page1->encrypt_to_always->isChecked();
 
 	if (m_encrypttoalways)
-		alwaysKeyID = m_page1->always_key->currentText().section(':', 0, 0);
+		alwaysKeyID = m_page1->always_key->itemData(m_page1->always_key->currentIndex(), Qt::ToolTipRole).toString();
 	else
 		alwaysKeyID.clear();
 
@@ -408,7 +444,7 @@ void kgpgOptions::updateSettings()
 		if (!server.contains(' ')) {
 			serverList.append(server);
 		} else {
-			server.replace(QRegExp(" .*"), "");	// Remove the " (Default)" section.
+			server.remove(QRegExp(" .*"));	// Remove the " (Default)" section.
 			serverList.prepend(server);		// Make it the first item in the list.
 		}
 	}
@@ -446,6 +482,9 @@ void kgpgOptions::updateSettings()
 	m_trayaction = m_page7->kcfg_LeftClick->currentIndex();
 	KGpgSettings::setLeftClick(m_trayaction);
 
+	m_mailUats = m_page7->kcfg_MailUats->currentIndex();
+	KGpgSettings::setMailUats(m_mailUats);
+
 	KGpgSettings::self()->writeConfig();
 	m_config->sync();
 
@@ -454,32 +493,15 @@ void kgpgOptions::updateSettings()
 
 void kgpgOptions::listKeys()
 {
-	KgpgInterface *iface = new KgpgInterface;
-	KgpgCore::KgpgKeyList keys = iface->readJoinedKeys(KgpgCore::TRUST_MARGINAL);
-	delete iface;
-
-	if (keys.size() == 0) {
-		ids += QString("0");
+	if (m_model->rowCount(QModelIndex()) == 0) {
+		ids += QString('0');
 		m_page1->file_key->addItem(i18nc("no key available", "none"));
+		m_page1->file_key->setModel(NULL);
 		m_page1->always_key->addItem(i18nc("no key available", "none"));
+		m_page1->always_key->setModel(NULL);
 	} else {
-		for (int i = 0; i < keys.size(); i++) {
-			KgpgCore::KgpgKey key = keys.at(i);
-
-			names += key.name();
-			ids += key.id();
-			QString text = key.id() + ": " + key.name() + " <" + key.email() + '>';
-			if (key.id() == alwaysKeyID)
-				alwaysKeyName = text;
-
-			if (key.secret()) {
-				m_page1->file_key->addItem(pixkeyDouble, text);
-				m_page1->always_key->addItem(pixkeyDouble, text);
-			} else {
-				m_page1->file_key->addItem(pixkeySingle, text);
-				m_page1->always_key->addItem(pixkeySingle, text);
-			}
-		}
+		m_page1->file_key->setModel(m_combomodel);
+		m_page1->always_key->setModel(m_combomodel);
 	}
 }
 
@@ -534,7 +556,8 @@ bool kgpgOptions::hasChanged()
 	if (m_page1->encrypt_to_always->isChecked() != m_encrypttoalways)
 		return true;
 
-	if (m_page1->encrypt_to_always->isChecked() && (m_page1->always_key->currentText().section(':', 0, 0) != alwaysKeyID))
+	if (m_page1->encrypt_to_always->isChecked() &&
+			(m_page1->always_key->itemData(m_page1->always_key->currentIndex(), Qt::ToolTipRole).toString()) != alwaysKeyID)
 		return true;
 
 	if (m_page4->gpg_conf_path->text() != KUrl::fromPath(gpgConfigPath).fileName())
@@ -551,7 +574,7 @@ bool kgpgOptions::hasChanged()
 
 	// Did the number of servers change?
 	if (m_page6->ServerBox->count() != serverList.size())
-	return true;
+		return true;
 
 	// Did the actual value of the servers change than?
 	for (int i = 0; i < m_page6->ServerBox->count(); i++) {
@@ -573,6 +596,9 @@ bool kgpgOptions::hasChanged()
 	if (m_page7->kcfg_LeftClick->currentIndex() != m_trayaction)
 		return true;
 
+	if (m_page7->kcfg_MailUats->currentIndex() != m_mailUats)
+		return true;
+
 	return false;
 }
 
@@ -612,6 +638,9 @@ bool kgpgOptions::isDefault()
 	if (m_page7->kcfg_LeftClick->currentIndex() != KGpgSettings::EnumLeftClick::KeyManager)
 		return false;
 
+	if (m_page7->kcfg_MailUats->currentIndex() != KGpgSettings::EnumMailUats::All)
+		return false;
+
 	return true;
 }
 
