@@ -67,6 +67,7 @@ public:
 	virtual QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;
 
 	KGpgNode *nodeForIndex(const QModelIndex &index) const;
+	KGpgKeyNode *findKeyNode(const QString &id) const;
 
 	KGpgRootNode *getRootNode() const;
 	QString statusCountMessage() const;
@@ -84,7 +85,7 @@ public Q_SLOTS:
 	void refreshKeys(KGpgKeyNode::List keys);
 	void refreshGroups();
 	void invalidateIndexes(KGpgNode *nd);
-	void refreshTrust(const KgpgCore::KgpgKeyTrust &trust, const QColor &color);
+	void refreshTrust(const KgpgCore::KgpgKeyTrust trust, const QColor &color);
 
 protected:
 	int rowForNode(KGpgNode *node) const;
