@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2008,2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
@@ -16,16 +16,17 @@
 
 #include <QObject>
 
-#include "kgpgtransaction.h"
+#include "kgpgeditkeytransaction.h"
 
 class QString;
 
 /**
- * \brief add a new user id to a key pair
+ * @brief add a new user id to a key pair
  */
-class KGpgAddUid: public KGpgTransaction {
+class KGpgAddUid: public KGpgEditKeyTransaction {
 	Q_OBJECT
 
+	Q_DISABLE_COPY(KGpgAddUid)
 public:
 	KGpgAddUid(QObject *parent, const QString &keyid, const QString &name, const QString &email = QString(), const QString &comment = QString());
 	virtual ~KGpgAddUid();
@@ -34,8 +35,6 @@ public:
 	void setEmail(const QString &email);
 	void setComment(const QString &comment);
 
-	QString getKeyid() const;
-
 protected:
 	virtual bool preStart();
 	virtual bool nextLine(const QString &line);
@@ -44,7 +43,6 @@ private:
 	QString m_name;
 	QString m_email;
 	QString m_comment;
-	QString m_keyid;
 };
 
 #endif // KGPGADDPHOTO_H
