@@ -76,11 +76,6 @@ bool ByteArrayColumnView::isByteTypeColored() const
     Q_D( const ByteArrayColumnView );
     return d->isByteTypeColored();
 }
-bool ByteArrayColumnView::offsetColumnVisible() const
-{
-    Q_D( const ByteArrayColumnView );
-    return d->offsetColumnVisible();
-}
 
 
 void ByteArrayColumnView::setByteArrayModel( AbstractByteArrayModel* _byteArrayModel )
@@ -177,12 +172,6 @@ void ByteArrayColumnView::fontChange( const QFont& oldFont )
     d->handleFontChange( oldFont );
 }
 
-void ByteArrayColumnView::toggleOffsetColumn( bool showOffsetColumn )
-{
-    Q_D( ByteArrayColumnView );
-    d->toggleOffsetColumn( showOffsetColumn );
-}
-
 
 QSize ByteArrayColumnView::minimumSizeHint() const
 {
@@ -192,13 +181,6 @@ QSize ByteArrayColumnView::minimumSizeHint() const
 }
 
 
-void ByteArrayColumnView::updateCursors()
-{
-    Q_D( ByteArrayColumnView );
-    d->updateCursors();
-}
-
-
 void ByteArrayColumnView::renderColumns( QPainter* painter, int cx, int cy, int cw, int ch )
 {
     Q_D( ByteArrayColumnView );
@@ -206,35 +188,6 @@ void ByteArrayColumnView::renderColumns( QPainter* painter, int cx, int cy, int
 }
 
 
-void ByteArrayColumnView::mousePressEvent( QMouseEvent* mouseEvent )
-{
-    Q_D( ByteArrayColumnView );
-    d->mousePressEvent( mouseEvent );
-}
-
-
-void ByteArrayColumnView::mouseMoveEvent( QMouseEvent* mouseEvent )
-{
-    Q_D( ByteArrayColumnView );
-    d->mouseMoveEvent( mouseEvent );
-}
-
-
-void ByteArrayColumnView::mouseReleaseEvent( QMouseEvent* mouseEvent )
-{
-    Q_D( ByteArrayColumnView );
-    d->mouseReleaseEvent( mouseEvent );
-}
-
-
-// gets called after press and release instead of a plain press event (?)
-void ByteArrayColumnView::mouseDoubleClickEvent( QMouseEvent* mouseEvent )
-{
-    Q_D( ByteArrayColumnView );
-    d->mouseDoubleClickEvent( mouseEvent );
-}
-
-
 ByteArrayColumnView::~ByteArrayColumnView()
 {
 }
